# SubscriptionCancellationPolicy


## Enum

* `ENDOFCURRENTTERM` (value: `'EndOfCurrentTerm'`)

* `ENDOFLASTINVOICEPERIOD` (value: `'EndOfLastInvoicePeriod'`)

* `SPECIFICDATE` (value: `'SpecificDate'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


